@@ -1,7 +1,7 @@
 # Version of Module
 
-__title__ = 'pyrpc'
+__title__ = 'pyrpc-discord'
 __author__ = 'bartick'
 __copyright__ = 'Copyright 2021 bartick'
 __license__ = 'MIT'
-__version__ = '1.1.1'
\ No newline at end of file
+__version__ = '1.1.2'
\ No newline at end of file
